# FoundationStereo: Zero-Shot Stereo Matching

:hammer: Refactored version of the original implementation of the [FoundationStereo](https://nvlabs.github.io/FoundationStereo/)

<p align="center">
  <img src="https://raw.githubusercontent.com/NVlabs/FoundationStereo/website/static/images/intro.jpg" width="800"/>
</p>

# License
This project is a refactored version of code originally developed by NVIDIA. The original code and its modifications are licensed under the terms specified in the [LICENSE](https://github.com/NVlabs/FoundationStereo/blob/master/LICENSE) file provided in the original repository.
